@@ -16,10 +16,9 @@ pub enum Error {
 use self::Error::*;
 
 impl error::Error for Error {
-
     fn source(&self) -> Option<&(dyn error::Error + 'static)> {
         match *self {
-            _ => None
+            _ => None,
         }
     }
 }
