@@ -1,8 +1,8 @@
-pub use self::error::Error;
-pub use self::message::FixedField;
-pub use self::message::Field;
-pub use self::message::Message;
 pub use self::connection::Connection;
+pub use self::error::Error;
+pub use self::message::Field;
+pub use self::message::FixedField;
+pub use self::message::Message;
 
 pub use self::client::Client;
 pub use self::params::ParamSet;
@@ -10,12 +10,14 @@ pub use self::params::ParamSet;
 pub mod spec;
 pub mod util;
 
+mod client;
+mod connection;
 mod error;
 mod message;
-mod connection;
 mod params;
-mod client;
+
+#[cfg(feature = "json")]
+mod message_json;
 
 #[cfg(test)]
 mod tests;
-
