@@ -1,27 +1,20 @@
-use super::spec;
-use super::message::FixedField;
 use super::message::Field;
+use super::message::FixedField;
 use super::message::Message;
+use super::spec;
 
 #[test]
 fn invalid_fixed_field() {
-    assert_eq!(
-        FixedField::new(&spec::FF_STATUS_CODE, "123").is_err(),
-        true
-    );
+    assert_eq!(FixedField::new(&spec::FF_STATUS_CODE, "123").is_err(), true);
 }
 
 #[test]
 fn ok_fixed_field() {
-    assert_eq!(
-        FixedField::new(&spec::FF_STATUS_CODE, "3").is_ok(),
-        true
-    );
+    assert_eq!(FixedField::new(&spec::FF_STATUS_CODE, "3").is_ok(), true);
 }
 
 #[test]
 fn sc_status_message() {
-
     // Move message creation into client.rs and just test what it creates
     let msg = Message::new(
         &spec::M_SC_STATUS,
@@ -30,7 +23,7 @@ fn sc_status_message() {
             FixedField::new(&spec::FF_MAX_PRINT_WIDTH, "999").unwrap(),
             FixedField::new(&spec::FF_PROTOCOL_VERSION, &spec::SIP_PROTOCOL_VERSION).unwrap(),
         ],
-        vec![]
+        vec![],
     );
 
     assert_eq!(msg.to_sip(), "9909992.00");
@@ -38,7 +31,6 @@ fn sc_status_message() {
 
 #[test]
 fn login_message() {
-
     let msg = Message::new(
         &spec::M_LOGIN,
         vec![
@@ -48,7 +40,7 @@ fn login_message() {
         vec![
             Field::new(spec::F_LOGIN_UID.code, "sip_username"),
             Field::new(spec::F_LOGIN_PWD.code, "sip_password"),
-        ]
+        ],
     );
 
     assert_eq!(msg.to_sip(), "9300CNsip_username|COsip_password|");
@@ -59,5 +51,3 @@ fn fixed_field_to_str() {
     let ff = FixedField::new(&spec::FF_MAX_PRINT_WIDTH, "999").unwrap();
     assert_eq!(ff.to_sip(), "999");
 }
-
-
